@@ -20,7 +20,9 @@ PO <- function (mu.link = "log")
                 rqres = expression(rqres(pfun="pPO", type="Discrete", ymin=0, y=y, mu=mu)), 
             mu.initial =expression({mu <- (y +mean(y))/2 } ),
               mu.valid = function(mu) all(mu > 0), 
-               y.valid = function(y)  all(y >= 0) 
+               y.valid = function(y)  all(y >= 0),
+                  mean = function(mu) mu,
+              variance = function(mu) mu
           ),
             class = c("gamlss.family","family"))
 }
